package cgl.util;
/* ====================================================================
 * The Indiana University Software License
 *
 * Copyright (c) 2001-2002 Indiana University
 * Pervasive Technology Labs
 * All rights reserved.
 *
 * The rest will added.
 * ====================================================================
 */
import java.io.*;
import java.util.*;

/**
 * @author Mehmet S. Aktas (maktas@indiana.edu)
 */

public class BootStrap {

  public BootStrap() {
  }

  /**
   * Returns the named file as a Property object.
   * <P>
   * @param fileName name of the file. Either full, or relative to the
   * current path, or must exist in the classpath or a JAR file.
   * @return properties
   * @throws NullPointerException if file name is null.
   * @throws Exception if file cannot be found or any other IO errors occur.
   */
  public static Properties loadProperties(String fileName) throws Exception {
    Properties p = null;


    if (fileName == null) {
      throw new NullPointerException("File name cannot be null.");
    }
    try {
      File file = new File(fileName);
      if (file.exists()) {
        p = new Properties();
        p.load(new FileInputStream(file));
        return p;
      }
    }
    catch (IOException ioe) {
      // do nothing
    }
    catch (Exception e) {
      throw e;
    }

    try {
      InputStream is = BootStrap.class.getResourceAsStream("/" + fileName);
      if (is != null) {
        p = new Properties();
        p.load(is);
      }
    }
    catch (Exception e) {
      System.out.println("Properties file not found in classpath.");
      throw e;
    }
    return p;
  }

  public static void main(String[] args) {

    try {
      Properties p = loadProperties("properties.properties");
      System.out.println(p);
    }
    catch (Exception ex) {
      ex.printStackTrace();
    }

  }
}
